: Package
name        = 'ripgrep'
version     = '12.1.1'
authors     = ['Andrew Gallant <jamslam@gmail.com']
description = '
ripgrep is a line-oriented search tool that recursively searches your current
directory for a regex pattern while respecting your gitignore rules. ripgrep
has first class support on Windows, macOS and Linux.'

documentation = 'https://github.com/BurntSushi/ripgrep'
homepage      = 'https://github.com/BurntSushi/ripgrep'
respository   = 'https://github.com/BurntSushi/ripgrep'
readme        = 'README.md'
keywords      = [ 'regex'
                , 'grep'
                , 'search'
                , 'pattern']
categories    = [ 'command-line-utilities'
                , 'text-processing']
license   = 'Unlicense OR MIT'
exclude   = ['HomebrewFormula']
build     = 'build.rs'
autotests = no
edition   = '2018'

bin = [bin ( bench -> no
           , path -> 'crates/core/main.rs'
           , name -> 'rg')]

test = [test ( name -> 'integration'
             , path -> 'tests/tests.rs')]

: Workspace
members = [ 'crates/globset'
          , 'crates/grep'
          , 'crates/cli'
          , 'crates/matcher'
          , 'crates/pcre2'
          , 'crates/printer'
          , 'crates/regex'
          , 'crates/searcher'
          , 'crates/ignore]

: Dependencies
bstr        = '0.2.12'
lazy_static = '1.1.0'
log         = '0.4.5'
num_cpus    = '1.8.0'
regex       = '1.3.5'
serde_json  = '1.0.23'
termcolor   = '1.1.0'
grep        = dependency ( version -> '0.2.7'
                         , path    -> 'crates/grep')
ignore      = dependency ( version -> '0.4.16'
                         , path    -> 'crates/ignore')
clap        = dependency ( version          -> '2.33.0'
                         , default-features -> no
                         , features         -> ['suggestions'])

-- I'm not sure how the following would be shown in memory.
-- Goff doesn't support keys with spaces at all, which this appears to depend on.
-- [target.'cfg(all(target_env = "musl", target_pointer_width = "64"))'.dependencies.jemallocator]
-- version = "0.3.0"

: Build-Dependencies
lazy_static = '1.1.0'
clap        = dependency ( version          -> '2.33.0'
                         , default-features -> no
                         , features         -> ['suggestions'])


: Dev-Dependencies
serde        = '1.0.77'
serde_derive = '1.0.77'
walkdir      = '2'

: Features
simd-accel = ['grep/simd-accel']
pcre2      = ['grep/pcre2']

: Profile
release = (debug -> 1)

: Package
metadata = (deb -> ( features -> ['pcre2']
                   , section  -> ['utils']
                   . assets = [ ['target/release/rg',      'usr/bin/',                        '755']
                              , ['COPYING',                'usr/share/doc/ripgrep/',          '644']
                              , ['LICENSE-MIT',            'usr/share/doc/ripgrep/',          '644']
                              , ['UNLICENSE',              'usr/share/doc/ripgrep/',          '644']
                              , ['CHANGELOG.md',           'usr/share/doc/ripgrep/CHANGELOG', '644']
                              , ['README.md',              'usr/share/doc/ripgrep/README',    '644']
                              , ['FAQ.md',                 'usr/share/doc/ripgrep/FAQ',       '644']
                               -- The man page is automatically generated by ripgrep's build
                               -- process, so this file isn't actually comitted. Instead, to create
                               -- a dpkg, either create a deployment/deb directory and copy the man
                               -- page to it, or use the 'ci/build-deb' script.
                               , ['deployment/deb/rg.1',   'usr/share/man/man1/rg.1', '644']
                               -- Similarly for shell completions
                               , ['deployment/deb/rg.bash', 'usr/share/bash-completion/completions/rg', '644']
                               , ['deployment/deb/rg.fish', 'usr/share/fish/vendor_completions.d/rg.fish', '644]
                               , ['deployment/deb/_rg', 'usr/share/zsh/vendor-completions/', '644']]]))

extended-description = '
ripgrep (rg) recursively searches your current directory for a regex pattern.
By default, ripgrep will respect your .gitignore and automatically skip hidden
files/directories and binary files.
'

+ dependency
| version
path             = Nothing
default-features = yes
features         = []

+ bin
| bench, path, name

+ test
| name, path